@@ -2,6 +2,6 @@ set -e
 
 cmd=read.py
 
-export PYTHONPATH=/home/webifier/hakmatak-1.1.0
+export PYTHONPATH=../../
 
 cacheTopDir=/tmp/hakmatak-$USER/cache
